<!--勤务人员-->
<template>
  <div>
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar title="勤务人员" left-arrow @click-left="(_) => $router.go(-1)
        " @click-right="showPopup('querySearchPopup')">
        <template #right>
          <van-icon name="search" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>

    <van-pull-refresh v-model="refreshing" class="van-hairline--top" @refresh="onRefresh">
      <van-list v-model="loading" :finished="finished" @load="onLoad" :immediate-check="false">
        <div v-for="item in listData" :key="item.id" class="device-item van-hairline--bottom">
          <div class="device-item-img">
            <!-- <van-icon name="manager" size="10rem" color="#c0c4cc" /> -->
            <van-image round width="100%"  :src="require('@/assets/img/mobile/comprehensiveEvaluation/avatar.svg')" />
          </div>

          <div class="device-item-text">
            <div class="device-item-content">
              <div>
                <div class="device-name">
                  姓名:{{ item.name }}
                </div>
                <div class="device-code">编号:{{ item.code }}</div>
                <div class="device-code">部门:{{ item.orgName }}</div>
                <div class="device-code">联系方式:{{ item.phone }}</div>
              </div>
              <div>
                <div v-if="item.cmgtDutyTeam" class="device-code">
                  {{ item.cmgtDutyTeam.name }}
                </div>
              </div>
            </div>

            <div class="device-item-content">
              <span class="sex-box">
                <van-image v-if="item.sex === '男'" width="100%"  :src="require('@/assets/img/mobile/comprehensiveEvaluation/male.svg')" />
                <van-image v-else width="100%"  :src="require('@/assets/img/mobile/comprehensiveEvaluation/female.svg')" />
                <!-- <span class="device-name-icon">
                  <van-icon name="label" />
                </span>
                {{ item.org != null ? item.org.name : '' }} -->
              </span>
              <span class="action-text" @click="handleDetail(item)">
                排班信息
                <!-- <span class="device-item-title">
                  <van-icon name="shop" />
                </span>
                {{ item.receiveTime }} -->
              </span>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>

    <!-- 列表筛选弹层 -->
    <QuerySearchPopup :querySearchPopup.sync="querySearchPopup" :customQueryPrams="customQueryPrams" :teamOpt="teamOpt"
      @searchData="searchData" />
  </div>
</template>

<script>
import DingDutyApi from '@/views/Manage/DingDutyApi.js'
import TeamMemberManage from '@/api/manager/duty/teamMemberManage.js'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

export default {
  name: 'MobileTeamMember',
  components: { QuerySearchPopup },
  // 勤务人员
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        team_id_: '', // 单位名称
        name_: '' // 人员姓名
      },
      listData: [],
      teamOpt: [],
      currentUser: {},
      loading: false, // 列表是否触发loading
      finished: false, // 列表是否加载完成
      refreshing: false, // 列表是否开始下拉刷新
      querySearchPopup: false // 搜索弹层
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const { pageSize, page, ...item } = this.customQueryPrams
      /*
       * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑
       *  为重新加工结构赋值的新请求配置参数
       * */
      const querys = [
        {
          group: 'id',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'team_id_', // 勤务小组
          relation: 'AND',
          value: ''
        },
        {
          group: 'id',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_', // 人员姓名
          relation: 'AND',
          value: ''
        }
      ]
      const escapeOpt = { team_id_: 'teamOpt' }
      return {
        pageBean: { pageSize, page },
        querys: querys.map((i) => {
          let value = item[i.property]
          let escape = this[escapeOpt[i.property]]
          if (!escape) return { ...i, value }
          value = this.dictionaryEscape(escape, value, {
            dictionaryType: false
          })
          return { ...i, value }
        }),
        sorter: [
          { direction: 'DESC', property: 'receive_time_' },
          { direction: 'DESC', property: 'ID_' }
        ]
      }
    }
  },
  created() {
    this.getTeamOpt()
    this.getListData()
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape(dictionary, val, option = {}) {
      if (!(Array.isArray(dictionary) && dictionary.length)) return ''
      option = {
        valueKey: 'value',
        labelKey: 'text',
        dictionaryType: true, // true 为转义 false 为翻译
        ...option
      }
      const { valueKey, labelKey, dictionaryType } = option
      let item =
        dictionary.find(
          (i) => i[dictionaryType ? valueKey : labelKey] === val
        ) || {}
      return item[dictionaryType ? labelKey : valueKey] || ''
    },

    // 勤务小组配置数组数据
    async getTeamOpt() {
      const { data } = await DingDutyApi.findTeams()
      this.teamOpt = [
        { value: '', text: '全部勤务小组' },
        ...data.map((i) => {
          return {
            value: i.id,
            text: i.name + ' 【' + i.orgName + '】'
          }
        })
      ]
    },

    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData((_) => (this.loading = false))
    },

    // 下拉时触发
    onRefresh() {
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData((_) => (this.refreshing = false))
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    },

    // 获取列表数据
    async getListData(callback) {
      const {
        data: { rows, total }
      } = await TeamMemberManage.pageQuery(this.queryParams)
      const { pageSize, page } = this.customQueryPrams
      this.listData = this.listData.concat(rows)
      this.$nextTick((_) => callback && callback())
      if (pageSize * page >= total) this.finished = true
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    },

    // 跳转设备详情
    handleDetail(item) {
      this.$router.push({
        name: 'MobileTeamMemberCalendar',
        query: {
          id: item.id,
          name: item.name,
          teamId: item.teamId
        }
      })
    }
  }
}
</script>

<style scoped lang="scss">
@import 'element-variables';

.sex-box {
  width: 50px;
  height: 50px;
}

.action-text {
  font-size: 50px;
  color: #469ff7;
}

::v-deep .van-pull-refresh__track {
  padding: 50px 40px;

  .van-list {
    display: flex;
    flex-direction: column;
    // row-gap: 40px;

    .device-item {
      background: #fff;
      box-sizing: border-box;
      color: $--color-text-regular;
      display: flex;
      align-items: center;
      width: 100%;
      box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);
      border-radius: 30px;
      padding: 30px 40px 30px 20px;
      margin-bottom: 40px;

      .device-item-img {
        display: flex;
        align-items: center;
        width: 300px;
        height: 280px;
        position: relative;
        // top: 20px;
      }

      .device-item-text {
        margin-left: 10px;
        width: calc(100% - 60px);
      }

      .device-item-content {
        display: flex;
        justify-content: space-between;
        align-items: center;

        div {
          &:last-child {
            display: flex;
            flex-direction: column;
            // align-items: flex-end;
          }
        }
      }

      .device-name {
        color: $--color-text-primary;
        font-size: 55px;
      }

      .device-name-icon {
        color: $--color-primary;
        margin-right: 2px;
      }

      .device-code {
        color: $--color-text-secondary;
        font-size: 50px;
      }

      .device-item-title {
        color: #49a1f9;
        margin-right: 2px;
      }


    }
  }
}

::v-deep .van-ellipsis {
  font-size: 14PX;
}

::v-deep .van-cell__title {
  span {
    font-size: 14px;
  }
}
</style>
